Description Usage Arguments Value Examples
View source: R/create_custom_enhanced_kwds.R
Create additional keywords by creating your own combinations of queries and choosen vectors.
1 | create_custom_enhanced_keywords(queries, suffix_vec = NULL)
|
queries |
vector of character strings. 'Bare' queries that will be fed to the Google Suggest. |
suffix_vec |
vector of character strings. Optional. It will generate additional combinations of keywords and prefix_vec contents will be placed AFTER the queries. Defaults to NULL |
vector of character strings with all combinations of queries and suffixes/prefixes
1 2 3 4 5 6 7 8 | ## Not run:
create_custom_enhanced_keywords(
queries = "mtcars",
suffix_vec = letters,
prefix_vec = c(0:9)
)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.