create_enhanced_keywords: Create additional keywords by creating combinations of...

Description Usage Arguments Value Examples

View source: R/create_basic_enhanced_kwds.R

Description

Create additional keywords by creating combinations of queries and letters and digits.

Usage

1

Arguments

queries

vector of character strings. 'Bare' queries that will feed the Google Suggest.

Value

vector of character strings with all combinations of queries and alphabet letters and digits

Examples

1
2
3
4
5
6
## Not run: 
  create_enhanced_keywords(
    queries = c("mtcars", "iris")
  )

## End(Not run)

Leszek-Sieminski/googleSuggestQueriesR documentation built on May 12, 2021, 1:34 p.m.