Description Usage Arguments Value Examples
Download suggested keywords for your keywords vector
1 | suggest_keywords(queries, lang = "en", interval = 0, enhanced = T)
|
queries |
vector of character strings. The queries that will be used to create suggestions |
lang |
character string. The language for which the suggestions will be created, formatted like: "en", "es", "fr", "de", "pl" etc. |
interval |
non-negative number. How many seconds must the function wait after the call to API? Defaults to 0, adjust if exceeded API limits encountered |
enhanced |
logical. Do you want to extract more suggestions by adding letters and digits after input queries? Defaults to TRUE |
vector of keywords suggestion
1 2 3 4 5 6 7 8 9 | ## Not run:
kwds <- suggest_keywords(
queries = c("mtcars", "iris"),
lang = "en",
interval = 1,
enhanced = T
)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.