Description Usage Arguments Value Examples
View source: R/suggest_single_kwd.R
Download suggested keywords for a single input query
1 | suggest_single_keyword(query, lang = "en", interval = 0)
|
query |
character string. The query that will be used to create suggestions |
lang |
character string. The language for which the suggestions will be created, formatted like: "en", "es", "fr", "de", "pl" etc. |
interval |
non-negative number. How many seconds must the function wait after the call to API? Defaults to 0, adjust if exceeded API limits encountered |
single column data frame with suggested queries
1 2 3 4 5 6 7 8 | ## Not run:
kwds <- suggest_single_keyword(
queries = "mtcars",
lang = "en",
interval = 1
)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.