Description Usage Arguments Value Examples
View source: R/create_basic_enhanced_kwds.R
Create additional keywords by creating combinations of queries and letters and digits.
1 | create_enhanced_keywords(queries)
|
queries |
vector of character strings. 'Bare' queries that will feed the Google Suggest. |
vector of character strings with all combinations of queries and alphabet letters and digits
1 2 3 4 5 6 | ## Not run:
create_enhanced_keywords(
queries = c("mtcars", "iris")
)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.